@@ -25,12 +25,13 @@ use warnings;
 use autodie;
 
 use List::MoreUtils qw(any);
-use Moo;
 
 use Lintian::Data;
-use Lintian::Tags qw(tag);
 
-with('Lintian::Check');
+use Moo;
+use namespace::clean;
+
+with 'Lintian::Check';
 
 our %KNOWN_FORMATS = map { $_ => 1 }
   ('1.0', '2.0', '3.0 (quilt)', '3.0 (native)', '3.0 (git)', '3.0 (bzr)');
@@ -42,9 +43,9 @@ our $KNOWN_FILES = Lintian::Data->new('debian-source-dir/known-files');
 sub source {
     my ($self) = @_;
 
-    my $info = $self->info;
+    my $processable = $self->processable;
 
-    my $dsrc = $info->index_resolved_path('debian/source/');
+    my $dsrc = $processable->index_resolved_path('debian/source/');
     my ($format_file, $git_pfile, $format, $format_extra);
 
     $format_file = $dsrc->child('format') if $dsrc;
@@ -57,13 +58,13 @@ sub source {
         $format_extra = '';
         die "unknown source format $format" unless $KNOWN_FORMATS{$format};
     } else {
-        tag 'missing-debian-source-format';
+        $self->tag('missing-debian-source-format');
         $format = '1.0';
         $format_extra = 'implicit';
     }
     if ($format eq '1.0') {
         $format_extra .= ' ' if $format_extra;
-        if ($info->diffstat) {
+        if ($processable->diffstat) {
             $format_extra .= 'non-native';
         } else {
             $format_extra .= 'native';
@@ -72,10 +73,9 @@ sub source {
     my $format_info = $format;
     $format_info .= " [$format_extra]"
       if $format_extra;
-    tag 'source-format', $format_info;
+    $self->tag('source-format', $format_info);
 
-    tag 'older-source-format', $format
-      if $OLDER_FORMATS{$format};
+    $self->tag('older-source-format', $format) if $OLDER_FORMATS{$format};
 
     return if not $dsrc;
 
@@ -84,16 +84,17 @@ sub source {
     if ($git_pfile and $git_pfile->is_open_ok and $git_pfile->size != 0) {
         my $git_patches_fd = $git_pfile->open;
         if (any { !/^\s*+#|^\s*+$/o} <$git_patches_fd>) {
-            my $dpseries = $info->index_resolved_path('debian/patches/series');
+            my $dpseries
+              = $processable->index_resolved_path('debian/patches/series');
             # gitpkg does not create series as a link, so this is most likely
             # a traversal attempt.
             if (not $dpseries or not $dpseries->is_open_ok) {
-                tag 'git-patches-not-exported';
+                $self->tag('git-patches-not-exported');
             } else {
                 my $series_fd = $dpseries->open;
                 my $comment_line = <$series_fd>;
                 my $count = grep { !/^\s*+\#|^\s*+$/o } <$series_fd>;
-                tag 'git-patches-not-exported'
+                $self->tag('git-patches-not-exported')
                   unless (
                     $count
                     && ($comment_line
@@ -106,16 +107,16 @@ sub source {
 
     for my $path ($dsrc->children) {
         my $file = $path->basename;
-        tag 'unknown-file-in-debian-source', $file
+        $self->tag('unknown-file-in-debian-source', $file)
           unless $KNOWN_FILES->known($file);
     }
 
-    my $options = $info->index_resolved_path('debian/source/options');
+    my $options = $processable->index_resolved_path('debian/source/options');
     if ($options and $options->is_open_ok) {
         my $fd = $options->open;
         while (<$fd>) {
-            tag 'debian-source-options-has-custom-compression-settings',
-              $1, "(line $.)"
+            $self->tag('debian-source-options-has-custom-compression-settings',
+                $1, "(line $.)")
               if m/^\s*(compression(?:-level)?\s*=\s+\S+)\n/;
         }
         close($fd);
